@@ -78,6 +78,7 @@ class ElasticSearchVisitor(Visitor):
     JOURNAL_ART_ID = 'artid'
     JOURNAL_YEAR = 'year'
     JOURNAL_FIELDS_MAPPING = {
+        JOURNAL_TITLE: '.'.join((JOURNAL_FIELDS_PREFIX, JOURNAL_TITLE_FOR_OLD_PUBLICATION_INFO)),
         JOURNAL_VOLUME: '.'.join((JOURNAL_FIELDS_PREFIX, JOURNAL_VOLUME)),
         JOURNAL_PAGE_START: '.'.join((JOURNAL_FIELDS_PREFIX, JOURNAL_PAGE_START)),
         JOURNAL_ART_ID: '.'.join((JOURNAL_FIELDS_PREFIX, JOURNAL_ART_ID)),
@@ -132,6 +133,7 @@ class ElasticSearchVisitor(Visitor):
             'thesis_info.institutions.record.$ref',
             'record_affiliations.record.$ref',
         ],
+        'fulltext': 'documents.attachment.content',
     }
     """Mapping from keywords to ElasticSearch fields.
     Note:
@@ -362,7 +364,10 @@ class ElasticSearchVisitor(Visitor):
         else:
             field_specifier = 'fields'
             field_specifier_value = fieldnames if isinstance(fieldnames, list) else [fieldnames]
-
+            # Can only use prefix queries on keyword, text and wildcard
+            # fields so in journal * searches with type date need to be removed
+            if 'publication_info.year' in field_specifier_value:
+                field_specifier_value.remove('publication_info.year')
         query = {
             'query_string': {
                 'query': escape_query_string_special_characters(value),
